==> apache-shardingsphere-elasticjob-3.0.2-src.zip: apache-shardingsphere-elasticjob-3.0.2-src-release/elasticjob-cloud/elasticjob-cloud-scheduler/src/test/java/org/apache/shardingsphere/elasticjob/cloud/scheduler/config/app/pojo/CloudAppConfigurationPOJOTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.elasticjob.cloud.scheduler.config.app.pojo;

import org.apache.shardingsphere.elasticjob.cloud.scheduler.config.app.CloudAppConfiguration;
import org.junit.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;
import static org.junit.Assert.assertTrue;

public final class CloudAppConfigurationPOJOTest {
    
    @Test
    public void assertToCloudAppConfiguration() {
        CloudAppConfigurationPOJO pojo = new CloudAppConfigurationPOJO();
        pojo.setAppName("app");
        pojo.setAppURL("url");
        pojo.setBootstrapScript("start.sh");
        CloudAppConfiguration actual = pojo.toCloudAppConfiguration();
        assertThat(actual.getAppName(), is("app"));
        assertThat(actual.getAppURL(), is("url"));
        assertThat(actual.getBootstrapScript(), is("start.sh"));
        assertThat(actual.getCpuCount(), is(1d));
        assertThat(actual.getMemoryMB(), is(128d));
        assertTrue(actual.isAppCacheEnable());
        assertThat(actual.getEventTraceSamplingCount(), is(0));
    }
    
    @Test
    public void assertFromCloudAppConfiguration() {
        CloudAppConfigurationPOJO actual = CloudAppConfigurationPOJO.fromCloudAppConfiguration(new CloudAppConfiguration("app", "url", "start.sh"));
        assertThat(actual.getAppName(), is("app"));
        assertThat(actual.getAppURL(), is("url"));
        assertThat(actual.getBootstrapScript(), is("start.sh"));
        assertThat(actual.getCpuCount(), is(1d));
        assertThat(actual.getMemoryMB(), is(128d));
        assertTrue(actual.isAppCacheEnable());
        assertThat(actual.getEventTraceSamplingCount(), is(0));
    }
}

==> apache-shardingsphere-elasticjob-3.0.4-src.zip: apache-shardingsphere-elasticjob-3.0.4-src-release/elasticjob-cloud/elasticjob-cloud-scheduler/src/test/java/org/apache/shardingsphere/elasticjob/cloud/scheduler/config/app/pojo/CloudAppConfigurationPOJOTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.elasticjob.cloud.scheduler.config.app.pojo;

import org.apache.shardingsphere.elasticjob.cloud.scheduler.config.app.CloudAppConfiguration;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertTrue;

class CloudAppConfigurationPOJOTest {
    
    @Test
    void assertToCloudAppConfiguration() {
        CloudAppConfigurationPOJO pojo = new CloudAppConfigurationPOJO();
        pojo.setAppName("app");
        pojo.setAppURL("url");
        pojo.setBootstrapScript("start.sh");
        CloudAppConfiguration actual = pojo.toCloudAppConfiguration();
        assertThat(actual.getAppName(), is("app"));
        assertThat(actual.getAppURL(), is("url"));
        assertThat(actual.getBootstrapScript(), is("start.sh"));
        assertThat(actual.getCpuCount(), is(1d));
        assertThat(actual.getMemoryMB(), is(128d));
        assertTrue(actual.isAppCacheEnable());
        assertThat(actual.getEventTraceSamplingCount(), is(0));
    }
    
    @Test
    void assertFromCloudAppConfiguration() {
        CloudAppConfigurationPOJO actual = CloudAppConfigurationPOJO.fromCloudAppConfiguration(new CloudAppConfiguration("app", "url", "start.sh"));
        assertThat(actual.getAppName(), is("app"));
        assertThat(actual.getAppURL(), is("url"));
        assertThat(actual.getBootstrapScript(), is("start.sh"));
        assertThat(actual.getCpuCount(), is(1d));
        assertThat(actual.getMemoryMB(), is(128d));
        assertTrue(actual.isAppCacheEnable());
        assertThat(actual.getEventTraceSamplingCount(), is(0));
    }
}
